# Pydbmate
> Another Python migration tool

[![Build Status](https://travis-ci.org/hmleal/pydbmate.svg?branch=master)](https://travis-ci.org/hmleal/pydbmate)


This project is inspired by ```dbmate```